summaryrefslogtreecommitdiff
path: root/hints
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2000-08-01 04:50:33 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2000-08-01 04:50:33 +0000
commit9422c00b50432b881d4068e835547b477a7bfcf5 (patch)
treec9d0d6aa47b13afd07464bad5c4b05af5b265103 /hints
parenta7867d0afe06715af8daed54e07334b50c98a192 (diff)
downloadperl-9422c00b50432b881d4068e835547b477a7bfcf5.tar.gz
Stash away the largefiles flags and libswanted.
p4raw-id: //depot/perl@6477
Diffstat (limited to 'hints')
-rw-r--r--hints/aix.sh63
-rw-r--r--hints/hpux.sh6
-rw-r--r--hints/linux.sh5
-rw-r--r--hints/solaris_2.sh12
4 files changed, 48 insertions, 38 deletions
diff --git a/hints/hpux.sh b/hints/hpux.sh
index ce15f552b4..ecfcb6d572 100644
--- a/hints/hpux.sh
+++ b/hints/hpux.sh
@@ -387,8 +387,10 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
case "$uselargefiles" in
''|$define|true|[yY]*)
# there are largefile flags available via getconf(1)
- # but we cheat for now.
- ccflags="$ccflags -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+ # but we cheat for now. (Keep that in the left margin.)
+ccflags_largefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+
+ ccflags="$ccflags $ccflags_largefiles"
if test -z "$ccisgcc" -a -z "$gccversion"; then
# The strict ANSI mode (-Aa) doesn't like large files.
diff --git a/hints/linux.sh b/hints/linux.sh
index 4fb2f89e7c..0fa46bd05d 100644
--- a/hints/linux.sh
+++ b/hints/linux.sh
@@ -282,7 +282,10 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
# after it has prompted the user for whether to use large files.
case "$uselargefiles" in
''|$define|true|[yY]*)
- ccflags="$ccflags -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+# Keep this in the left margin.
+ccflags_largefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+
+ ccflags="$ccflags $ccflags_largefiles"
;;
esac
EOCBU
diff --git a/hints/solaris_2.sh b/hints/solaris_2.sh
index 6e84bace62..21b0b0e4f5 100644
--- a/hints/solaris_2.sh
+++ b/hints/solaris_2.sh
@@ -374,9 +374,15 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
# after it has prompted the user for whether to use large files.
case "$uselargefiles" in
''|$define|true|[yY]*)
- ccflags="$ccflags `getconf LFS_CFLAGS 2>/dev/null`"
- ldflags="$ldflags `getconf LFS_LDFLAGS 2>/dev/null`"
- libswanted="$libswanted `getconf LFS_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+
+# Keep these in the left margin.
+ccflags_largefiles="`getconf LFS_CFLAGS 2>/dev/null`"
+ldflags_largefiles="`getconf LFS_LDFLAGS 2>/dev/null`"
+libswanted_largefiles="`getconf LFS_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+
+ ccflags="$ccflags $ccflags_largefiles"
+ ldflags="$ldflags $ldflags_largefiles"
+ libswanted="$libswanted $libswanted_largefiles"
;;
esac
EOCBU
diff --git a/hints/aix.sh b/hints/aix.sh
index d6f3dd78e0..8a29b93e5b 100644
--- a/hints/aix.sh
+++ b/hints/aix.sh
@@ -206,30 +206,29 @@ EOCBU
cat > UU/uselargefiles.cbu <<'EOCBU'
case "$uselargefiles" in
''|$define|true|[yY]*)
- lfcflags="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
- lfldflags="`getconf XBS5_ILP32_OFFBIG_LDFLAGS 2>/dev/null`"
+# Keep these at the left margin.
+ccflags_largefiles="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
+ldflags_largefiles="`getconf XBS5_ILP32_OFFBIG_LDFLAGS 2>/dev/null`"
# _Somehow_ in AIX 4.3.1.0 the above getconf call manages to
# insert(?) *something* to $ldflags so that later (in Configure) evaluating
# $ldflags causes a newline after the '-b64' (the result of the getconf).
# (nothing strange shows up in $ldflags even in hexdump;
# so it may be something in the shell, instead?)
# Try it out: just uncomment the below line and rerun Configure:
-# echo >&4 "AIX 4.3.1.0 $lfldflags mystery" ; exit 1
+# echo >&4 "AIX 4.3.1.0 $ldflags_largefiles mystery" ; exit 1
# Just don't ask me how AIX does it, I spent hours wondering.
# Therefore the line re-evaluating lfldflags: it seems to fix
# the whatever it was that AIX managed to break. --jhi
- lfldflags="`echo $lfldflags`"
- lflibs="`getconf XBS5_ILP32_OFFBIG_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
- case "$lfcflags$lfldflags$lflibs" in
+ ldflags_largefiles="`echo $ldflags_largefiles`"
+# Keep this at the left margin.
+libswanted_largefiles="`getconf XBS5_ILP32_OFFBIG_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+ case "$ccflags_largefiles$ldflags_largefiles$libs_largefiles" in
'');;
- *) ccflags="$ccflags $lfcflags"
- ldflags="$ldflags $lfldflags"
- libswanted="$libswanted $lflibs"
+ *) ccflags="$ccflags $ccflags_largefiles"
+ ldflags="$ldflags $ldflags_largefiles"
+ libswanted="$libswanted $libswanted_largefiles"
;;
esac
- lfcflags=''
- lfldflags=''
- lflibs=''
;;
esac
EOCBU
@@ -279,18 +278,18 @@ int main (void)
EOCP
set size
if eval $compile_ok; then
- lfcpuwidth=`./size`
- echo "You are running on $lfcpuwidth bit hardware."
+ qacpuwidth=`./size`
+ echo "You are running on $qacpuwidth bit hardware."
else
dflt="32"
echo " "
echo "(I can't seem to compile the test program. Guessing...)"
rp="What is the width of your CPU (in bits)?"
. ./myread
- lfcpuwidth="$ans"
+ qacpuwidth="$ans"
fi
$rm -f size.c size
- case "$lfcpuwidth" in
+ case "$qacpuwidth" in
32*)
cat >&4 <<EOM
Bzzzt! At present, you can only perform a
@@ -299,8 +298,8 @@ EOM
exit 1
;;
esac
- lfcflags="`getconf XBS5_LP64_OFF64_CFLAGS 2>/dev/null`"
- lfldflags="`getconf XBS5_LP64_OFF64_LDFLAGS 2>/dev/null`"
+ qacflags="`getconf XBS5_LP64_OFF64_CFLAGS 2>/dev/null`"
+ qaldflags="`getconf XBS5_LP64_OFF64_LDFLAGS 2>/dev/null`"
# See jhi's comments above regarding this re-eval. I've
# seen similar weirdness in the form of:
#
@@ -309,8 +308,8 @@ EOM
# error messages from 'cc -E' invocation. Again, the offending
# string is simply not detectable by any means. Since it doesn't
# do any harm, I didn't pursue it. -- sh
- lfldflags="`echo $lfldflags`"
- lflibs="`getconf XBS5_LP64_OFF64_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+ qaldflags="`echo $qaldflags`"
+ qalibs="`getconf XBS5_LP64_OFF64_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
# -q32 and -b32 may have been set by uselargefiles or user.
# Remove them.
ccflags="`echo $ccflags | sed -e 's@-q32@@'`"
@@ -322,15 +321,15 @@ EOM
trylist="`echo $trylist | sed -e 's@^ar @@' -e 's@ ar @ @g' -e 's@ ar$@@'`"
ar="ar -X64"
nm_opt="-X64 $nm_opt"
# Note: Placing the 'lfcflags' variable into the 'ldflags' string
# is NOT a typo. ldlflags is passed to the C compiler for final
# linking, and it wants -q64 (-b64 is for ld only!).
- case "$lfcflags$lfldflags$lflibs" in
+ case "$qacflags$qaldflags$qalibs" in
'');;
- *) ccflags="$ccflags $lfcflags"
- ldflags="$ldflags $lfcflags"
- lddlflags="$lfldflags $lddlflags"
- libswanted="$libswanted $lflibs"
+ *) ccflags="$ccflags $qacflags"
+ ldflags="$ldflags $qacflags"
+ lddqalags="$qaldflags $lddqalags"
+ libswanted="$libswanted $qalibs"
;;
esac
case "$ccflags" in
@@ -344,10 +343,10 @@ EOM
# Don't try backwards compatibility
bincompat="$undef"
d_bincompat5005="$undef"
- lfcflags=''
- lfldflags=''
- lflibs=''
- lfcpuwidth=''
+ qacflags=''
+ qaldflags=''
+ qalibs=''
+ qacpuwidth=''
;;
esac
EOCBU
@@ -206,30 +206,29 @@ EOCBU
# Just don't ask me how AIX does it, I spent hours wondering.
- # Therefore the line re-evaluating lfldflags: it seems to fix
+ # Therefore the line re-evaluating ldflags_largefiles: it seems to fix
# the whatever it was that AIX managed to break. --jhi
@@ -322,15 +321,15 @@ EOM
ar="ar -X64"
nm_opt="-X64 $nm_opt"
- # Note: Placing the 'lfcflags' variable into the 'ldflags' string
- # is NOT a typo. ldlflags is passed to the C compiler for final
+ # Note: Placing the 'qacflags' variable into the 'ldflags' string
+ # is NOT a typo. ldqalags is passed to the C compiler for final
# linking, and it wants -q64 (-b64 is for ld only!).